%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%      DLS IN WELLBORES     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear % to remove all variables from the workspace
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 1. LOADING THE RTDD FROM DIFFERENT SECTIONS OF THE WELL
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load C47IncAzDLS-8_5
Z=X;
load C47IncAzDLS-12_25
Y=X;
load C47IncAzDLS-17_5
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 2. COMBINING THE DATA FILES TO OBTAIN A SINGLE DATA FILE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f=fieldnames(X);
for i=1:length(f)
    W.(f{i})=[X.(f{i});Y.(f{i});Z.(f{i})];
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3. REMOVING RTTD FROM OPERATIONS OTHER THAN DRILLING
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
DBTM=W.DBTM(W.DBTM==W.DMEA);
DMEA=W.DMEA(W.DBTM==W.DMEA);
INC=W.INC(W.DBTM==W.DMEA);
AZI=W.AZI(W.DBTM==W.DMEA);
DL_S=W.DLS(W.DBTM==W.DMEA);
WOB=W.WOB(W.DBTM==W.DMEA);
HKL=W.HKL(W.DBTM==W.DMEA);  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 4. SORTING TO AVOID REPITION OF DATA DURING RECORDING 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
md=unique(DMEA, 'stable');
incazicoord = unique(DMEA, 'stable');%DMEA for survey points.
azis = unique(AZI,'stable');% Azimuth for survey points
incl=unique(INC,'stable');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 5. ASSIGN THE VALUES OF INCLINATION and AZIMUTH FROM 1 TO n-1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
inc1=incl(1:(end-1));
inc2=inc1(1:(end));
azi1=azis(1:(length(inc1)));
azi2=azis(1:(length(inc2)));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 6. CALCULATE EASTING, NORTHING AND TVD FOR PROJECTION OF WELL
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculating the ratio 'F' from dogleg
dogleg=acosd(cosd(inc1).*cosd(inc2)+sind(inc1).*sind(inc2)...
    .*(cosd(azi2-azi1)));
F1=(2./dogleg).*(180./pi).*tand(dogleg./2);
F=fillmissing(F1,'linear','EndValues','nearest');%removing the NaN values 
%by interpolation
%Calculating the change in TVD(Z)
dZ=F.*diff(md(1:length(incl)))./2.*(cosd(inc1)+cosd(inc2));
Za=cumsum(dZ);%Cumulative sum of elements in dZ
%Calculating the change in Northings(X)
dX=F.*diff(md(1:length(incl)))./2.*(sind(inc1).*cosd(azi1)+sind(inc2)...
    .*cosd(azi2));
Xa=cumsum(dX);%Cumulative sum of elements in dX
%Calculating the change in Eastings(Y)
dY=F.*diff(md(1:length(incl)))./2.*(sind(inc1).*sind(azi1)+sind(inc2)...
    .*sind(azi2));
Ya=cumsum(dY);%Cumulative sum of elements in dY
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 7. CALCULATE  DLS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
DLS1=abs(acosd(cosd(W.INC(1:(end-1)))...
    .*cosd(W.INC(2:(end)))+sind(W.INC(1:(end-1))).*sind(W.INC(2:(end)))...
    .*(cosd(W.AZI(2:(end))-W.AZI(1:(end-1))))))./abs(diff(W.DMEA))*30;
%Convert obtained inf entries to NaN entries
DLS1(isinf(DLS1)) = NaN;
% Fill leading and trailing NaN entries with their nearest neighbors using
% linear interpolation
DLS=fillmissing(DLS1,'linear','EndValues','nearest');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 8. REPORT THE ALLOWABLE LIMITS OF CALCULATED DLS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
DLSNew(1:length(DLS))=0;
DLSNew(DLS>3)=3;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 9. PLOTTING 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1)
subplot(1,3,1)%VERTICAL PROJECTION ON W-E PLANE
plot(Ya,Za,'b','linewidth', 1.2);
grid on
legend('(a) Vertical View on W-E Plane')
xlabel('Easting [m]')
ylabel('TVD [m]')
set(gca,'ydir','reverse')
subplot(1,3,2)%VERTICAL PROJECTION ON S-N PLANE
plot(Xa,Za,'b','linewidth', 1.2);
grid on
legend('(b) Vertical View on S-N Plane')
xlabel('Northing [m]')
ylabel('TVD [m]')
set(gca,'ydir','reverse')
subplot(1,3,3)%PLAN PROJECTION
plot(Xa,Ya,'b','linewidth', 1.2)
grid on
legend('(c) Plan View')
xlabel('Northing [m]')
ylabel('Easting [m]')
set(gca,'ydir','reverse')
figure(2)% 3D PRESENTETION OF THE WELL
plot3(Xa,Ya,Za,'b','linewidth',1.2)
grid on
legend('(a) 3-D View of 34/10-C-47 wellbore')
xlabel('Northing [m]')
ylabel('Easting [m]')
zlabel('TVD [m]')
set(gca,'zdir','reverse')
set(gca,'ydir','reverse')
figure(3)% COMPUTED DLS AND DLS FROM THE SURVEY FILE
subplot(1,3,1)
plot(DLS,W.DMEA(2:end),'b','linewidth',1.2);%Calculated DLS from the model
grid on
hold on
legend('(a) Calculated DLS')
xlabel('DLS [Deg/30 m]')
ylabel('Measured Depth [m]')
set(gca,'ydir','reverse')
subplot(1,3,2)
plot(W.DLS,W.DMEA,'r','linewidth',1.2) % DLS from the file 
legend('(b) DLS from SURVEY DATA')
grid on
xlabel('DLS [Deg/30 m]')
ylabel('Measured Depth [m]')
set(gca,'ydir','reverse')
subplot(1,3,3)
plot(abs(W.DLS(2:end)-DLS),W.DMEA(2:end),'k','linewidth',1.2)%difference...
%between calculated DLS and DLS from the file
legend('(c) Difference between Calculated DLS and DLS from SURVEY DATA')
grid on
xlabel('DLS [Deg/30 m]')
ylabel('Measured Depth [m]')
set(gca,'ydir','reverse')
figure(4)%REPORTING THE ALLOWABLE DLS
plot(DLS,W.DMEA(2:end),'b','linewidth',1.2) % Dogleg from file.
%title('REPORTING THE ALLOWABLE DLS LIMIT FOR 34/10-C-47 WELL')
hold on
plot(DLSNew,W.DMEA(2:end),'r-','linewidth',1.2)% rEPORTING WHEN dls > 3deg/30 m
grid on 
xlabel('DLS[deg/ 30 m]')
ylabel('Measured Depth [m]')
legend('Computed DLS','Indicator of DLS limits')
set(gca,'ydir','reverse')
figure(5)%HKL AND BLOCK POSITION
subplot(1,2,1)
plot(W.HKL,W.DMEA,'r','linewidth',1.2)
set(gca,'ydir','reverse')
legend('HOOK LOAD')
xlabel('Hook Load [Ton]')
ylabel('Measured Depth [m]')
grid on
subplot(1,2,2)
plot(W.BPOS,W.DMEA,'linewidth',1.2)
set(gca,'ydir','reverse')
legend('BLOCK POSITION')
grid on
xlabel('Block Position [Ton]')
ylabel('Measured Depth [m]')
figure(6)% AZIMUTH AND INCLINATION
plot(azis,md,'linewidth', 1.2)
hold on 
plot(incl,md(1:length(incl)),'linewidth', 1.2)
%title('Azimuth and Inclination for 34/10-C-47');
set(gca,'ydir','reverse')
grid on
legend('AZIMUTH','INCLINATION')
set(gca,'yLim',[1400 4500])
xlabel('Azimuth/Inclination[degree]')
ylabel('Measured Depth [m]')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 10. TESTING THE CODE TO EVALUATE ERRORS 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
result=runtests('ThesisC47');