%DLS IN WELLBORES
clear  % to remove all variables from the workspace
% IMPORT THE RTDD FROM DIFFERENT SECTIONS OF THE WELL 

P=importdata('F-4_ACTUAL.txt'); 
% Generating a matrix fr the imported data 
MD=P(1:end,1);%Measured Depth 
Inc=P(1:end,2);%Wellbore Inclination 
Az=P(1:end,3); %Wellbore Azimuth 
DLSg=P(1:end,9);%Wellbore Dogleg Severity 

% ASSIGN THE VALUES OF INCLINATION and AZIMUTH FROM 1 TO n-1
inc1=Inc(1:(end-1));
inc2=Inc(2:(end));
azi1=Az(1:(end-1));
azi2=Az(2:end);

% CALCULATE  DLS
dogleg=acosd(cosd(inc1).*cosd(inc2)+sind(inc1).*sind(inc2).*(cosd(azi2-azi1)));
dm=diff(MD);
DLS=dogleg.*30./dm;

% REPORT THE ALLOWABLE LIMITS OF CALCULATED DLS
DLSNew(1:length(DLS))=0;
DLSNew(DLS>3)=1;

% CALCULATE EASTING, NORTHING AND TVD FOR PROJECTION OF WELL
F1=2*180/pi.*tand(dogleg./2)./dogleg;%Calculating the ratio 'F' from dogleg
F=fillmissing(F1,'linear','EndValues','nearest');%removing the NaN values 
%by interpolation
%Calculating the change in TVD(Z)
dZ=F.*dm./2.*(cosd(inc1)+cosd(inc2));
Za=cumsum(dZ);%Cumulative sum of elements in dZ
%Calculating the change in Northings(X)
dX=F.*dm./2.*(sind(inc1).*cosd(azi1)+sind(inc2).*cosd(azi2));
Xa=cumsum(dX);%Cumulative sum of elements in dX,%6787142.43=NS UTM [m]
%Calculating the change in Eastings(Y)
dY=F.*dm./2.*(sind(inc1).*sind(azi1)+sind(inc2).*sind(azi2));
Ya=cumsum(dY);%Cumulative sum of elements in dY, 460998.13=EW UTM [m]

%PLOTTING 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1)
%VERTICAL PROJECTION
subplot(1,3,1)
%plot((sqrt(Xa.^2+Ya.^2)),Za,'b','linewidth', 1.2)
plot(Ya,Za,'b','linewidth', 1.2);
grid on
legend('(a) Vertical View on W-E Plane')
xlabel('Easting [m]')
ylabel('TVD [m]')
set(gca,'ydir','reverse')
subplot(1,3,2)
plot(Xa,Za,'b','linewidth', 1.2);
grid on
legend('(b) Vertical View on S-N Plane')
xlabel('Northing [m]')
ylabel('TVD [m]')
set(gca,'ydir','reverse')
%PLAN PROJECTION
subplot(1,3,3)
plot(Xa,Ya,'b','linewidth', 1.2)
grid on
legend('(c) Plan View')
xlabel('Northing [m]')
ylabel('Easting [m]')
set(gca,'ydir','reverse')
% 3D PRESENTETION OF THE WELL
figure(2)
plot3(Xa,Ya,Za,'b','linewidth',1.2)
grid on
legend('(b)3-D View of 15/9-F-4 wellbore')
xlabel('Northing [m]')
ylabel('Easting [m]')
zlabel('TVD [m]')
set(gca,'zdir','reverse')
set(gca,'ydir','reverse')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%  DLS 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(3)
subplot(1,3,1)
plot(DLS,MD(2:end),'b','linewidth',1.2);%Calculated DLS from the model
grid on
hold on
legend('(a) Calculated DLS')
xlabel('DLS [Deg/30 m]')
ylabel('Measured Depth [m]')
set(gca,'ydir','reverse')
subplot(1,3,2)
plot(DLSg,MD,'r','linewidth',1.2) % DLS from the file 
legend('(b) DLS from SURVEY DATA')
grid on
xlabel('DLS [Deg/30 m]')
ylabel('Measured Depth [m]')
set(gca,'ydir','reverse')
subplot(1,3,3)
plot(abs(DLSg(2:end)-DLS),MD(2:end),'k','linewidth',1.2)%difference...
%between calculated DLS and DLS from the file
legend('(c) Difference between Calculated DLS and DLS from SURVEY DATA')
grid on
xlabel('DLS [Deg/30 m]')
ylabel('Measured Depth [m]')
set(gca,'ydir','reverse')
%REPORTING THE ALLOWABLE DLS
figure(4)
plot(DLS,MD(2:end),'b','linewidth',1.2) % Dogleg from file.
hold on
plot(3*DLSNew,MD(2:end),'r','linewidth',1.2)% REPORTING WHEN DLS > 3deg/30 m
grid on 
xlabel('DLS[deg/ 30 m]')
ylabel('Measured Depth [m]')
legend('Computed DLS','Indicator of DLS limits')
set(gca,'ydir','reverse')
figure(6)
plot(Az,MD,'linewidth', 1.2)
hold on 
plot(Inc,MD,'linewidth', 1.2)
title('Azimuth and Inclination for 15/9-F-4');
set(gca,'ydir','reverse')
grid on
legend('AZIMUTH','INCLINATION')
set(gca,'yLim',[200 3600])
xlabel('Azi/Inc[degree]')
ylabel('Measured Depth [m]')