% .CALCULATING THE SIDE FORCE AT EVERY LAST DRILLING RUN IN A WELL
% SECTION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%clear all
T = xlsread('para');%read the xlsx file conyaing the sideforce parameters
%DS parameters
a=T(1,5);%average dry weight of DP (kg/m)
b=T(2,1);%length of HWDP
c=T(2,5);%average dry weight of HWDP (kg/m)
d=T(3,1);%length of DC
e=T(3,5);%average dry weight of DC (kg/m)
f=T(4,1);%length of PDM
g=T(4,5);%average dry weight of PDM (kg/m)
h=T(5,1);%length of PDC
i=T(5,5);%average dry weight of PDC (kg/m)
MW=1.3; % assumed mud weight
Dsteel=7.85;%density of steel
WOB=10;%assumed WOB (tons)
fr=0.2;%friction factor
%1. Estimation of SF and tensions at the BHA
wtd=b*c+d*e+f*g+h*i;%Average dry weight of the BHA
BF=1-(MW./Dsteel);%bouyance factor
wtt=BF*wtd./1000;%wet weight of the BHA
wdp=BF*500*a./1000; %weight of DP at every subinterval 
%inclination and azimuth are estimated fom the plot of INC and AZI against
%measured depth at every 500 m from the BHA (starting 4281 m to 4399 m  )
inc1=93.01;
inc2=93.83;
azi1=179.1;
azi2=180;
%side force at the BHA
SF1=wtt*sind((inc1+inc2)/2);
%Tension below BHA 
T1=0;%assuming that tension below the BHA=WOB
T2=T1+wtt*cosd((inc1+inc2)/2)+fr*SF1;%tension at the top of BHA 
%2. Estimation of SF and tensions at the first subinterval 
%inclination and azimuth are estimated from 3781 m to 4281 m 
inc_1=93.01;
inc_2=93.84;
azi_1=179.1;
azi_2=179.5;
SF2=wdp*sind((inc_1+inc_2)/2);%side force above the BHA
T3=T2+fr*SF2+wdp*cosd((inc_1+inc_2)/2); % tension above the first subinterval
%3. Estimation of SF and tensions at the second subinterval 
%inclination and azimuth are estimated from 3281 m to 3781 m 
Inc_1=93.01;
Inc_2=80.52;
Azi_1=179.1;
Azi_2=183.8;
SF3=wdp*(sind(Inc_1+Inc_2)/2);%side force at the BHA
T4=T3+fr*SF3+BF*wdp*cosd((Inc_1+Inc_2)/2);%tension above  the second subinterval
%4. Estimation of SF and tensions at the third subinterval 
%inclination and azimuth are estimated from 2781 m to 3281 m 
Inc1=93.01;
Inc2=90.33;
Azi1=179.1;
Azi2=138.2;
SF4=wdp*(sind(Inc1+Inc2)./2);
T5=T4+fr*SF4+BF*wdp*cosd((Inc1+Inc2)./2);%tension above  the third  subinterval
%5. Estimation of SF and tensions at the forth subinterval 
%inclination and azimuth are estimated from 2281 m to 2781 m
In1=93.01;
In2=62.89;
Az1=179.1;
Az2=104.5;
SF5=wdp*(sind(In1+In2)/2);
T6=T5+fr*SF5+BF*wdp*cosd((In1+In2)/2);%tension above  the forth  subinterval
%6. Estimation of SF and tensions at the fifth subinterval 
%inclination and azimuth are estimated from 1788 m to 2288 m
In_1=93.01;
In_2=62.4;
Az_1=179.1;
Az_2=107.3;
SF6=wdp*sind((In_1+In_2)/2);
T7=T6+fr*SF6+BF*wdp*cosd((In_1+In_2)/2);%tension above  the fifth subinterval
%7. Estimation of SF and tensions at the sixth subinterval 
%inclination and azimuth are estimated from 1500 m to 1781 m
in_1=93.01;
in_2=59.6;
az_1=179.1;
az_2=139.8;
SF7=wdp*sind((in_1+in_2)/2);
T8=T7+fr*SF7+BF*wdp*cosd((in_1+in_2)/2);%tension above  the sixth subinterval
%COMBINING THE OBTAINED RESULTS
J=abs([SF1,SF2,SF3,SF4,SF5,SF6,SF7])';%Combining the estimated SF
N=[T2, T3,T4,T5,T6,T7,T8]'; %Combining the estimated tensions
D=[4288,3788,3288,2788,2288,1788,1500]';%Depth of subintervals
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%. REPORTING WHENEVER SF > threshold values 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
SFNew=zeros(length(J),1);
for j=1:length(J)
if J(j)>1
    SFNew(j)=1;
else
   SFNew(j)=0;
end 
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% : PLOTTING
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1)
plot(N,D,'-.dk','MarkerEdgeColor','k','MarkerFaceColor','k');
%title('Computed side force and string tension for 34/10-C-47 wellbore');
grid on 
hold on 
plot(J,D,'-.sr','MarkerEdgeColor','r','MarkerFaceColor','r');
legend('String Tension','Estimated Side force','location','best');
ylabel('Measured Depth [m]')
xlabel('Weight [Ton]')
set(gca,'ydir','reverse')
set(gca,'yLim',[1400 4500])
figure(2)
plot(SFNew,D,'-.ob','MarkerEdgeColor','b','MarkerFaceColor','b');
%title('Computed and allowable side force for 34/10-C-47 wellbore');
hold on 
plot(J,D,'-.sr','MarkerEdgeColor','r','MarkerFaceColor','r');
legend('Allowable Side force','Estimated Side force','location','best');
ylabel('Measured Depth [m]')
xlabel('Weight [Ton]')
grid on
set(gca,'ydir','reverse')
set(gca,'yLim',[1400 4500])