% .CALCULATING THE SIDE FORCE AT EVERY LAST DRILLING RUN IN A WELL
% SECTION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%clear all
T = xlsread('para');%read the xlsx file conyaing the sideforce parameters
%DS parameters
a=T(1,5);%average dry weight of DP (kg/m)
b=T(2,1);%length of HWDP
c=T(2,5);%average dry weight of HWDP (kg/m)
d=T(3,1);%length of DC
e=T(3,5);%average dry weight of DC (kg/m)
f=T(4,1);%length of PDM
g=T(4,5);%average dry weight of PDM (kg/m)
h=T(5,1);%length of PDC
i=T(5,5);%average dry weight of PDC (kg/m)
MW=1.3; % assumed mud weight
Dsteel=7.85;%density of steel
WOB=10;%assumed WOB (tons)
fr=0.2;%friction factor

%1. Estimation of SF and tensions at the BHA
wtd=b*c+d*e+f*g+h*i;%Average dry weight of the BHA
BF=1-(MW./Dsteel);%bouyance factor
wtt=BF*wtd./1000;%wet weight of the BHA
wdp=BF*500*a./1000; %weight of DP at every section
%Net=wtt./1000-WOB; %net weight on BHA in tons
%inclination and azimuth are estimated fom the plot of INC and AZI against
%measured depth at every 500 m from the BHA (starting 3382 m to 3500 m  )
inc1=52.87;
inc2=53.02;
azi1=105.6;
azi2=106.7;
Dogleg1=abs(acosd(cosd(inc1).*cosd(inc2)+sind(inc1).*sind(inc2)...
    *(cosd(azi2-azi1))));
%SF1=2*Net*(sind(Dogleg1./2));%side force at the BHA
SF1=wtt*sind((inc1+inc2)/2);
%Tension below BHA 
T1=0;%assuming that tension below the BHA=WOB
T2=wtt*cosd((inc1+inc2)/2)+fr*SF1;%tension at the top of BHA 
%2. Estimation of SF and tensions at the first subinterval 
%inclination and azimuth are estimated from 2882 m to 3382 m 
inc_1=52.87;
inc_2=50.82;
azi_1=105.6;
azi_2=105.2;
Dogleg2=abs(acosd(cosd(inc_1).*cosd(inc_2)+sind(inc_1).*sind(inc_2)...
    *(cosd(azi_2-azi_1))));
SF2=wdp*sind((inc_1+inc_2)/2);%side force above the BHA
T3=T2+fr*SF2+wdp*cosd((inc_1+inc_2)/2); % tension above the first subinterval
%3. Estimation of SF and tensions at the second subinterval 
%inclination and azimuth are estimated from 2382 m to 2882 m 
Inc_1=52.87;
Inc_2=13.45;
Azi_1=105.6;
Azi_2=146.4;
Dogleg3=abs(acosd(cosd(Inc_1).*cosd(Inc_2)+sind(Inc_1).*sind(Inc_2)...
    *(cosd(Azi_2-Azi_1))));
SF3=wdp*(sind(Inc_1+Inc_2)/2);%side force at the BHA
T4=T3+fr*SF3+BF*wdp*cosd((Inc_1+Inc_2)/2);%tension above  the second subinterval
%4. Estimation of SF and tensions at the third subinterval 
%inclination and azimuth are estimated from 1882 m to 2382 m 
Inc1=52.87;
Inc2=23.5;
Azi1=105.6;
Azi2=253.1;
Dogleg4=abs(acosd(cosd(Inc1).*cosd(Inc2)+sind(Inc1).*sind(Inc2)...
    *(cosd(Azi2-Azi1))));
SF4=wdp*(sind(Inc1+Inc2)./2);
T5=T4+fr*SF4+BF*wdp*cosd((Inc1+Inc2)./2);%tension above  the third  subinterval
%5. Estimation of SF and tensions at the forth subinterval 
%inclination and azimuth are estimated from 1382 m to 1882 m
In1=52.87;
In2=16.68;
Az1=105.6;
Az2=246.5;
Dogleg5=abs(acosd(cosd(In1).*cosd(In2)+sind(In1).*sind(In2)...
    *(cosd(Az2-Az1))));
SF5=wdp*(sind(In1+In2)/2);
T6=T5+fr*SF5+BF*wdp*cosd((In1+In2)/2);%tension above  the forth  subinterval

%6. Estimation of SF and tensions at the fifth subinterval 
%inclination and azimuth are estimated from 1328 m to 1382 m
In_1=52.87;
In_2=14.77;
Az_1=105.6;
Az_2=250.1;
Dogleg6=abs(acosd(cosd(In_1).*cosd(In_2)+sind(In_1).*sind(In_2)...
    *(cosd(Az_2-Az_1))));
SF6=wdp*sind((In_1+In_2)/2);
T7=T6+fr*SF6+BF*wdp*cosd((In_1+In_2)/2);%tension above  the fifth subinterval
%COMBINING THE OBTAINED RESULTS
J=[SF1,SF2,SF3,SF4,SF5,SF6]';%Combining the estimated SF
N=[T2, T3,T4,T5,T6,T7]'; %Combining the estimated tensions
D=[3500,3382,2882,2382,1882,1382]';%Depth of subintervals
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%. REPORTING WHENEVER SF > threshold values 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
SFNew=zeros(length(J),1);
for j=1:length(J)
if J(j)>1
    SFNew(j)=1;
else
   SFNew(j)=0;
end 
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% : PLOTTING
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1)
plot(N,D,'-.dk','MarkerEdgeColor','k','MarkerFaceColor','k');
% title('Computed side force and string tension for 15/9-F-11 wellbore');
grid on 
hold on 
plot(J,D,'-.sr','MarkerEdgeColor','r','MarkerFaceColor','r');
legend('String Tension','Computed Side force','location','best');
ylabel('Measured Depth [m]')
xlabel('Weight [Ton]')
set(gca,'ydir','reverse')
set(gca,'yLim',[1300 3600])
figure(2)
plot(SFNew,D,'-.ob','MarkerEdgeColor','b','MarkerFaceColor','b');
% title('Computed and allowable side force for 15/9-F-12 wellbore');
hold on 
plot(J,D,'-.sr','MarkerEdgeColor','r','MarkerFaceColor','r');
legend('Indication of allowable Side force limit','Computed Side force','location','best');
ylabel('Measured Depth [m]')
xlabel('Weight [Ton]')
grid on
set(gca,'ydir','reverse')
set(gca,'yLim',[1300 3600])